/* $Id: $ */

/* Copyright (C) 1997 Sverre Hvammen Johansen and Terje Mjoes,
 * Department of Informatics, University of Oslo.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "cim.h"

/******************************************************************************
                                              Rutinerin (test)               */

/* Utf|rer en slags intest som brukes ved overforing av name parametere.
 * Rin() brukes ved vanlige in tester */

char __rrin (__pty q, __pty p)
{
  if (
#if __CHAR_UNSIGNED__
       (signed char)
#endif
       q->plev <
#if __CHAR_UNSIGNED__
       (signed char)
#endif
       p->plev || q->pref[p->plev] != p)
    return (__FALSE);
  return (__TRUE);
}
